@@ -1,9 +1,9 @@
 /*
  *  Phusion Passenger - https://www.phusionpassenger.com/
- *  Copyright (c) 2010-2017 Phusion Holding B.V.
+ *  Copyright (c) 2010-2025 Asynchronous B.V.
  *
  *  "Passenger", "Phusion Passenger" and "Union Station" are registered
- *  trademarks of Phusion Holding B.V.
+ *  trademarks of Asynchronous B.V.
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a copy
  *  of this software and associated documentation files (the "Software"), to deal
@@ -110,7 +110,9 @@ public:
 					sizeof(unsigned long);
 
 				while (data < last_long) {
-					result = result * 33 + *((unsigned long *) data);
+					unsigned long l = 0;
+				    memcpy(&l, data, sizeof(unsigned long));
+					result = result * 33 + l;
 					data += sizeof(unsigned long);
 				}
 
